#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var nice_color_palettes_1 = __importDefault(require("nice-color-palettes"));
var chalk_1 = __importDefault(require("chalk"));
var utils_1 = require("./utils");
var clearScrollback = function () {
    return process.stdout.write("\u001b[H\u001b[2J\u001b[3J");
};
var createGrid = function () {
    var pointPositions = [];
    var columns = process.stdout.columns;
    var rows = process.stdout.rows;
    for (var x = 0; x < rows; x++) {
        for (var y = 0; y < columns; y++) {
            pointPositions.push([x, y]);
        }
    }
    return pointPositions;
};
var drawGridTimeout;
var startDrawLoop = function (pointPositions) {
    var nColours = 5;
    var randomPalette = utils_1.shuffle(utils_1.pickRandom(nice_color_palettes_1.default).slice(0, nColours));
    var noiseZ = 0;
    var noiseZVel = 0.0000022;
    drawGridTimeout = setInterval(function () {
        clearScrollback();
        pointPositions.forEach(function (position) {
            var y = position[0], x = position[1];
            var z = utils_1.noise3D(x, y, noiseZ);
            var nChars = 9;
            var zMult = Math.abs(Math.floor(z * nChars));
            var colourMap = Math.floor(utils_1.mapRange(zMult, 4, nChars - 1, 0, nColours - 1));
            var char = " ";
            if ([0, 1, 2, 3].includes(zMult))
                char = " ";
            if (zMult === 4)
                char = ".";
            if (zMult === 5)
                char = "-";
            if (zMult === 6)
                char = "o";
            if (zMult === 7)
                char = "+";
            if (zMult === 8)
                char = "x";
            if (zMult === 9)
                char = "X";
            var color = randomPalette[colourMap];
            process.stdout.write(chalk_1.default.hex(color)(char));
            noiseZ += noiseZVel;
        });
    }, 60);
};
var init = function () {
    var grid = createGrid();
    startDrawLoop(grid);
};
init();
var initTimeout;
process.stdout.on("resize", function () {
    clearScrollback();
    clearInterval(drawGridTimeout);
    clearTimeout(initTimeout);
    initTimeout = setTimeout(function () { return init(); }, 200);
});
